using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using System.IO;

namespace FaxSOAP
{
    public partial class frmMain : Form
    {
        public frmMain()
        {
            InitializeComponent();
        }

        #region CustomFunctions

        private void SetFile(TextBox txtFileField)
        {
            try
            {
                OpenFileDialog FileDiag = new OpenFileDialog();

                if (FileDiag.ShowDialog() != DialogResult.Cancel)
                {
                    txtFileField.Text = FileDiag.FileName;
                }
                else
                {
                    txtFileField.Text = "";
                }
            }
            catch (Exception eX)
            {
                string error = eX.ToString();
                MessageBox.Show(error);
            }
        }

        private string GetFileName(string strFileLocation)
        {
            return System.IO.Path.GetFileName(strFileLocation);
        }
        
        private byte[] GetFileContents(string strFileLocation)
        {
            //
            // Read files in bytes, convert to Base64String and return in byte[]
            //
            using (FileStream reader = new FileStream(strFileLocation, FileMode.Open))
            {
                byte[] buffer = new byte[reader.Length];
                reader.Read(buffer, 0, (int)reader.Length);
                string strContent = Convert.ToBase64String(buffer);

                System.Text.ASCIIEncoding encoding = new System.Text.ASCIIEncoding();
                return encoding.GetBytes(strContent);
            }
        }

        private void SendFax()
        {
            TNZSendFax.SendFaxServiceClient SOAPClient = new TNZSendFax.SendFaxServiceClient();

            string strSender, strToken, strReference, strSendTime, strUTCSendTime, strChargeCode, strResolution;
            string strAttention, strCompany, strNumber, strMessage, strListFileName1, strListFileName2;
            string strFileName1, strFileName2, strFileName3, strFileName4, strFileName5;

            byte[] strListFileContents1, strListFileContents2;
            byte[] strFileContents1, strFileContents2, strFileContents3, strFileContents4, strFileContents5;

            strSender = txtSender.Text;
            strToken = txtToken.Text;
            strReference = txtReference.Text;
            strSendTime = "";
            strUTCSendTime = "";
            strChargeCode = "";
            strResolution = "High";

            strAttention = "";
            strCompany = "";
            strNumber = "";
            strMessage = "";
            strListFileName1 = "";
            strListFileContents1 = null;
            strListFileName2 = "";
            strListFileContents2 = null;

            strFileName1 = "";
            strFileContents1 = null;
            strFileName2 = "";
            strFileContents2 = null;
            strFileName3 = "";
            strFileContents3 = null;
            strFileName4 = "";
            strFileContents4 = null;
            strFileName5 = "";
            strFileContents5 = null;

            //
            // Retrieve Fax Destination based on multi or single target
            //
            if (rdMultiTargetNo.Checked == true)
            {
                strAttention = txtAttention.Text;
                strCompany = txtCompany.Text;
                strNumber = txtNumber.Text;
            }
            if (rdMultiTargetYes.Checked == true)
            {
                if (File.Exists(txtListFile1.Text))
                {
                    strListFileName1 = GetFileName(txtListFile1.Text);
                    strListFileContents1 = GetFileContents(txtListFile1.Text);
                }

                if (File.Exists(txtListFile2.Text))
                {
                    strListFileName2 = GetFileName(txtListFile2.Text);
                    strListFileContents2 = GetFileContents(txtListFile2.Text);
                }
            }

            //
            // Retrieve file(s) to fax
            //
            if (txtFile1.Text != "" && File.Exists(txtFile1.Text))
            {
                strFileName1 = GetFileName(txtFile1.Text);
                strFileContents1 = GetFileContents(txtFile1.Text);
            }

            if (txtFile2.Text != "" && File.Exists(txtFile2.Text))
            {
                strFileName2 = GetFileName(txtFile2.Text);
                strFileContents2 = GetFileContents(txtFile2.Text);
            }

            if (txtFile3.Text != "" && File.Exists(txtFile3.Text))
            {
                strFileName3 = GetFileName(txtFile3.Text);
                strFileContents3 = GetFileContents(txtFile3.Text);
            }

            if (txtFile4.Text != "" && File.Exists(txtFile4.Text))
            {
                strFileName4 = GetFileName(txtFile4.Text);
                strFileContents4 = GetFileContents(txtFile4.Text);
            }

            if (txtFile5.Text != "" && File.Exists(txtFile5.Text))
            {
                strFileName5 = GetFileName(txtFile5.Text);
                strFileContents5 = GetFileContents(txtFile5.Text);
            }

            //
            // Send Fax by SOAP interface
            //
            string strResult = SOAPClient.send_fax(strSender, strToken, strReference, strSendTime, strUTCSendTime, strChargeCode, strResolution, strAttention, strCompany,
                                                    strNumber, strMessage, strListFileName1, strListFileContents1, strListFileName2, strListFileContents2, strFileName1, strFileContents1,
                                                    strFileName2, strFileContents2, strFileName3, strFileContents3, strFileName4, strFileContents4, strFileName5, strFileContents5);

            //
            // Display Result
            //
            MessageBox.Show(strResult);
        }

        #endregion

        #region UIEvents

        private void btnFindListFile1_Click(object sender, EventArgs e)
        {
            SetFile(txtListFile1);
        }

        private void btnFindListFile2_Click(object sender, EventArgs e)
        {
            SetFile(txtListFile2);
        }

        private void btnFindFile1_Click(object sender, EventArgs e)
        {
            SetFile(txtFile1);
        }

        private void btnFindFile2_Click(object sender, EventArgs e)
        {
            SetFile(txtFile2);
        }

        private void btnFindFile3_Click(object sender, EventArgs e)
        {
            SetFile(txtFile3);
        }

        private void btnFindFile4_Click(object sender, EventArgs e)
        {
            SetFile(txtFile4);
        }

        private void btnFindFile5_Click(object sender, EventArgs e)
        {
            SetFile(txtFile5);
        }

        private void rdMultiTargetNo_CheckedChanged(object sender, EventArgs e)
        {
            if (rdMultiTargetNo.Checked == true)
            {
                txtCompany.Enabled = true;
                txtAttention.Enabled = true;
                txtNumber.Enabled = true;

                txtListFile1.Enabled = false;
                btnFindListFile1.Enabled = false;
                txtListFile2.Enabled = false;
                btnFindListFile2.Enabled = false;
            }
        }

        private void rdMultiTargetYes_CheckedChanged(object sender, EventArgs e)
        {
            if (rdMultiTargetYes.Checked == true)
            {
                txtCompany.Enabled = false;
                txtAttention.Enabled = false;
                txtNumber.Enabled = false;

                txtListFile1.Enabled = true;
                btnFindListFile1.Enabled = true;
                txtListFile2.Enabled = true;
                btnFindListFile2.Enabled = true;
            }
        }

        private void btnSend_Click(object sender, EventArgs e)
        {
            if (txtSender.Text == "")
            {
                MessageBox.Show("Please enter outbound email address");
                txtSender.Focus();
                return;
            }
            if (txtToken.Text == "")
            {
                MessageBox.Show("Please enter user token");
                txtToken.Focus();
                return;
            }
            if (rdMultiTargetNo.Checked == true)
            {
                if (txtNumber.Text == "")
                {
                    MessageBox.Show("Please specify fax number");
                    txtNumber.Focus();
                    return;
                }
            }
            if (rdMultiTargetYes.Checked == true)
            {
                if (txtListFile1.Text == "" && txtListFile2.Text == "")
                {
                    MessageBox.Show("Please specify at least 1 list file(s) to send");
                    btnFindListFile1.Focus();
                    return;
                }
            }
            if (txtFile1.Text == "" && txtFile2.Text == "" && txtFile3.Text == "" && txtFile4.Text == "" && txtFile5.Text == "")
            {
                MessageBox.Show("Please specify at least 1 document(s) to send");
                btnFindFile1.Focus();
                return;
            }
            SendFax();
        }

        #endregion

        private void btnClose_Click(object sender, EventArgs e)
        {
            this.Close();
        }
    }
}